"""
Module is entry point for migration generation
"""

import os
from argparse import ArgumentParser, Namespace

from configs_core.migration.generator import MigrationGenerator

from .config import MIGRATION_DIR
from .dump.services import LUNA_PLATFORM
from .settings.all_settings import SETTINGS


def getCmdOptions() -> Namespace:
    """
    Collects passed arguments
        --migration name
        --config - path to config file
        --luna-config - luna-configurator address

    Returns:
        object with arguments and its values
    """
    parser = ArgumentParser(description="Configs migration generator")
    parser.add_argument("name", metavar="name", type=str, nargs=1, help="migration name. 36 chars max length")
    defaultConfigFilePath = os.path.join(os.path.abspath(os.path.dirname(__file__)), "config.conf")
    parser.add_argument("--config", default=defaultConfigFilePath, type=str, help="path to config")

    cmdArgs = parser.parse_args()

    return cmdArgs


if __name__ == "__main__":
    MigrationGenerator(
        getCmdOptions().name[0], services=LUNA_PLATFORM, migrationDir=MIGRATION_DIR, settingsStore=SETTINGS
    ).generate()
