"""
Configs migration

Generation datetime: 2023-05-23 12:54:50.126544
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "32234ee5"
DOWN_REVISION = "c39109d1"


def settingUpgradeFunction(settings: dict):
    settings["cached_data"] = {"faces_lists": {"exclude": [], "include": None}}
    return settings


def settingDowngradeFunction(settings: dict):
    if "cached_data" in settings:
        del settings["cached_data"]
    return settings


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="DESCRIPTORS_CACHE",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "cache_enabled": {"type": "boolean"},
                "updating_cache_interval": {"type": "number", "exclusiveMinimum": 0},
                "matching_settings": {
                    "type": "object",
                    "properties": {
                        "thread_count": {"type": "integer", "minimum": 0},
                        "tasks_count": {"type": "integer", "minimum": 0},
                        "batch_size": {"type": "integer", "minimum": 0},
                    },
                    "description": "matcher lib settings",
                    "additionalProperties": False,
                },
                "rpc_settings": {
                    "type": "object",
                    "properties": {
                        "timeouts": {
                            "type": "object",
                            "properties": {
                                "connect_timeout": {"type": "integer", "minimum": 0},
                                "request_timeout": {"type": "integer", "minimum": 0},
                                "response_timeout": {"type": "integer", "minimum": 0},
                            },
                            "description": "matcher lib settings",
                            "additionalProperties": False,
                        },
                        "pool_size": {"type": "integer", "minimum": 0},
                    },
                    "description": "matcher lib settings",
                    "additionalProperties": False,
                },
            },
            "description": "python matcher descriptor caching settings",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "cache_enabled": {"type": "boolean"},
                "updating_cache_interval": {"type": "number", "exclusiveMinimum": 0},
                "matching_settings": {
                    "type": "object",
                    "properties": {
                        "thread_count": {"type": "integer", "minimum": 0},
                        "tasks_count": {"type": "integer", "minimum": 0},
                        "batch_size": {"type": "integer", "minimum": 0},
                    },
                    "description": "matcher lib settings",
                    "additionalProperties": False,
                },
                "rpc_settings": {
                    "type": "object",
                    "properties": {
                        "timeouts": {
                            "type": "object",
                            "properties": {
                                "connect_timeout": {"type": "integer", "minimum": 0},
                                "request_timeout": {"type": "integer", "minimum": 0},
                                "response_timeout": {"type": "integer", "minimum": 0},
                            },
                            "description": "matcher lib settings",
                            "additionalProperties": False,
                        },
                        "pool_size": {"type": "integer", "minimum": 0},
                    },
                    "description": "matcher lib settings",
                    "additionalProperties": False,
                },
                "cached_data": {
                    "type": "object",
                    "properties": {
                        "faces_lists": {
                            "type": "object",
                            "properties": {
                                "exclude": {
                                    "type": ["array", "null"],
                                    "items": {
                                        "type": "string",
                                        "pattern": "^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$",
                                    },
                                    "maxItems": 1000,
                                    "description": "lists that should not be cached (set to null to disable)",
                                    "additionalProperties": False,
                                },
                                "include": {
                                    "type": ["array", "null"],
                                    "items": {
                                        "type": "string",
                                        "pattern": "^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$",
                                    },
                                    "maxItems": 1000,
                                    "description": "lists that should be cached (set to null to disable)",
                                    "additionalProperties": False,
                                },
                            },
                            "description": "faces lists cache rules",
                            "additionalProperties": False,
                        },
                        "additionalProperties": False,
                    },
                    "description": "cached matching data",
                    "additionalProperties": False,
                },
            },
            "description": "python matcher descriptor caching settings",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "cache_enabled": True,
            "updating_cache_interval": 2,
            "matching_settings": {
                "thread_count": 0,
                "batch_size": 20,
                "tasks_count": 10,
            },
            "rpc_settings": {
                "timeouts": {
                    "connect_timeout": 20,
                    "request_timeout": 60,
                    "response_timeout": 60,
                },
                "pool_size": 100,
            },
        },
        newDefaultValue={
            "cache_enabled": True,
            "updating_cache_interval": 2,
            "matching_settings": {
                "thread_count": 0,
                "batch_size": 20,
                "tasks_count": 10,
            },
            "rpc_settings": {
                "timeouts": {
                    "connect_timeout": 20,
                    "request_timeout": 60,
                    "response_timeout": 60,
                },
                "pool_size": 100,
            },
            "cached_data": {"faces_lists": {"exclude": [], "include": None}},
        },
        oldDescription="LUNA Python Matcher descriptor caching settings",
        newDescription="LUNA Python Matcher descriptor caching settings",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=settingUpgradeFunction,
        settingDowngradeFunction=settingDowngradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-python-matcher"],
        newServices=["luna-python-matcher"],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
