"""
Configs migration

Generation datetime: 2023-12-01 13:58:28.893748
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "5ad592b2"
DOWN_REVISION = "b9c5a47a"


limitationsToModify: List[LimitationToModify] = []

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_API_PLUGINS_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {},
            "additionalProperties": True,
        },
        defaultValue={},
        description="LUNA API plugins settings",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_API_PLUGINS_SETTINGS")
