"""
Configs migration

Generation datetime: 2024-07-09 08:38:40.599343
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "5b4de77b"
DOWN_REVISION = "19230084"


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_OBJECTS_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-objects",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-objects",
        },
        oldDescription="Address of service for storing objects",
        newDescription="Address of service for storing objects",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-lambda-tasks-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-api",
            "luna-lambda-tasks-unit",
            "luna-remote-sdk",
            "luna-tasks",
            "luna-video-agent",
        ],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
