"""
Configs migration

Generation datetime: 2024-11-12 09:50:06.188916
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "7415e5db"
DOWN_REVISION = "0a60491a"


def upgradeAsu(setting: dict):
    setting["luna_video_agent"] = False
    return setting


def downgradeAsu(setting: dict):
    setting.pop("luna_video_agent")
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="DEFAULT_HUMAN_DESCRIPTOR_VERSION",
        oldValidationSchema={"type": "integer"},
        newValidationSchema={"type": "integer"},
        oldDefaultValue=116,
        newDefaultValue=116,
        oldDescription="default human descriptor version to work with",
        newDescription="default human descriptor version to work with",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-events",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
        ],
        newServices=[
            "luna-events",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-video-agent",
        ],
    ),
    LimitationToModify(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
                "luna_lambda": {"type": "boolean"},
                "luna_video_manager": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
                "luna_lambda",
                "luna_video_manager",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
                "luna_lambda": {"type": "boolean"},
                "luna_video_manager": {"type": "boolean"},
                "luna_video_agent": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
                "luna_lambda",
                "luna_video_manager",
                "luna_video_agent",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
            "luna_lambda": False,
            "luna_video_manager": False,
        },
        newDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
            "luna_lambda": False,
            "luna_video_manager": False,
            "luna_video_agent": False,
        },
        oldDescription="whether to use nested optional services",
        newDescription="whether to use nested optional services",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=upgradeAsu,
        settingDowngradeFunction=downgradeAsu,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
            "luna-video-agent",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
            "luna-video-agent",
        ],
    ),
    LimitationToModify(
        limitationName="DEFAULT_FACE_DESCRIPTOR_VERSION",
        oldValidationSchema={"type": "integer"},
        newValidationSchema={"type": "integer"},
        oldDefaultValue=62,
        newDefaultValue=62,
        oldDescription="default face descriptor version to work with",
        newDescription="default face descriptor version to work with",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
        ],
        newServices=[
            "luna-api",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-video-agent",
        ],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_HUMAN_TRACKER_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_VIDEO_SETTINGS")

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5240", "api_version": 1},
        description="LUNA Video agent address",
        services=["luna-admin", "luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_AGS_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for ags estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_BASIC_ATTRIBUTES_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for basic attributes estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_BODY_ATTRIBUTES_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for body attributes estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_BODY_DESCRIPTOR_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for body descriptor estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_BODY_WARP_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for body warp estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_DEEPFAKE_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {
                        "real_threshold": {
                            "type": "number",
                            "minimum": 0,
                            "maximum": 1,
                        },
                        "estimation_mode": {"type": "integer", "enum": [1, 2]},
                    },
                    "description": "FSDK deepfake estimator settings",
                    "additionalProperties": False,
                },
            },
            "description": "settings for sdk deepfake estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {"real_threshold": 0.5, "estimation_mode": 2},
        },
        description="luna-video-agent settings for liveness estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_EMOTIONS_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for emotions estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_EYES_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for eyes estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_FACE_DESCRIPTOR_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for face descriptor estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_FACE_LANDMARKS5_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for face landmarks5 estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_FACE_WARP_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for face warp estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_FACE_WARP_QUALITY_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for face warp quality estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_GAZE_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for gaze estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_GLASSES_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for glasses estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_HEAD_POSE_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for head pose estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_HUMAN_DETECTOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for human detection in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_HUMAN_TRACKER_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {
                        "detector_step": {"type": "integer", "minimum": 1},
                        "scale_result_size": {"type": "integer", "minimum": 1},
                        "skip_frames": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                    "description": "tracker settings",
                },
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 100},
            "estimator_settings": {
                "detector_step": 7,
                "scale_result_size": 640,
                "skip_frames": 18,
            },
        },
        description="luna-video-agent settings for trackengine",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_LIVENESS_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {"real_threshold": {"type": "number", "minimum": 0, "maximum": 1}},
                    "description": "FSDK one shot liveness settings",
                    "additionalProperties": False,
                },
            },
            "description": "settings for sdk liveness estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {"real_threshold": 0.5},
        },
        description="luna-video-agent settings for liveness estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_MASK_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for mask estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_MOUTH_ATTRIBUTES_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for mouth attributes estimation in handlers",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-video-agent service",
        services=["luna-admin", "luna-api"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_HUMAN_TRACKER_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {
                        "detector_step": {"type": "integer", "minimum": 1},
                        "scale_result_size": {"type": "integer", "minimum": 1},
                        "skip_frames": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                    "description": "tracker settings",
                },
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 100},
            "estimator_settings": {
                "detector_step": 7,
                "scale_result_size": 640,
                "skip_frames": 18,
            },
        },
        description="luna-remote-sdk settings for trackengine",
        services=["luna-remote-sdk"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_VIDEO_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "storage": {"type": "string"},
                "max_size": {"type": "integer", "minimum": 1},
                "timeouts": {
                    "type": "object",
                    "properties": {
                        "request": {"type": "number", "exclusiveMinimum": 0},
                        "connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_read": {"type": "number", "exclusiveMinimum": 0},
                    },
                    "description": "timeouts in seconds",
                    "additionalProperties": False,
                },
                "frame_pool_size": {"type": "integer", "minimum": 1},
                "ffmpeg_thread_count": {"type": "integer", "minimum": 0},
            },
            "description": "sdk video processing settings",
            "additionalProperties": False,
        },
        defaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "frame_pool_size": 10,
            "ffmpeg_thread_count": 0,
            "storage": "./videos",
            "max_size": 1024,
            "timeouts": {
                "connect": 30.0,
                "request": 60.0,
                "sock_connect": 10.0,
                "sock_read": 60.0,
            },
        },
        description="luna-remote-sdk video processing settings",
        services=["luna-remote-sdk"],
        groupNames=["luna-platform"],
    )

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_AGS_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_BASIC_ATTRIBUTES_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_BODY_ATTRIBUTES_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_BODY_DESCRIPTOR_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_BODY_WARP_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_DEEPFAKE_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_EMOTIONS_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_EYES_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_FACE_DESCRIPTOR_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_FACE_LANDMARKS5_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_FACE_WARP_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_FACE_WARP_QUALITY_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_GAZE_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_GLASSES_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_HEAD_POSE_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_HUMAN_DETECTOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_HUMAN_TRACKER_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_LIVENESS_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_MASK_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_MOUTH_ATTRIBUTES_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_TIMEOUTS")
