"""Tests for the 'configs submodule."""

import os
import sys
from unittest import TestCase

from fastjsonschema import validate

sys.path.append(os.path.dirname(os.path.dirname(__file__)))


class TestConfigsCorrectness(TestCase):
    """Test settings' correctness."""

    def testSettingsCorrectness(self):
        """
        Check each `setting` has the same name as the key in the `SETTINGS` dict.
        """
        from configs.settings.all_settings import SETTINGS

        for settingName, setting in SETTINGS.items():
            with self.subTest(setting=settingName):
                self.assertTrue(settingName.isupper(), "Set setting name upper")
                # I need private attribute, so... pylint: disable-msg=W0212
                self.assertEqual(settingName, setting._settingName, "Set setting name the same")

    def test_default_values(self):
        """
        Check default values.
        """
        from configs.settings.all_settings import SETTINGS

        for setting in SETTINGS.values():
            with self.subTest(setting_name=setting._settingName):
                validate(setting.schema, setting.default)
